from _typeshed import Incomplete

TCS_MULTILINE: int
CBRS_ALIGN_LEFT: int
CBRS_ALIGN_TOP: int
CBRS_ALIGN_RIGHT: int
CBRS_ALIGN_BOTTOM: int
CBRS_ALIGN_ANY: int
CBRS_BORDER_LEFT: int
CBRS_BORDER_TOP: int
CBRS_BORDER_RIGHT: int
CBRS_BORDER_BOTTOM: int
CBRS_BORDER_ANY: int
CBRS_TOOLTIPS: int
CBRS_FLYBY: int
CBRS_FLOAT_MULTI: int
CBRS_BORDER_3D: int
CBRS_HIDE_INPLACE: int
CBRS_SIZE_DYNAMIC: int
CBRS_SIZE_FIXED: int
CBRS_FLOATING: int
CBRS_GRIPPER: int
CBRS_ORIENT_HORZ: Incomplete
CBRS_ORIENT_VERT: Incomplete
CBRS_ORIENT_ANY: Incomplete
CBRS_ALL: int
CBRS_NOALIGN: int
CBRS_LEFT: Incomplete
CBRS_TOP: Incomplete
CBRS_RIGHT: Incomplete
CBRS_BOTTOM: Incomplete
SBPS_NORMAL: int
SBPS_NOBORDERS: int
SBPS_POPOUT: int
SBPS_OWNERDRAW: int
SBPS_DISABLED: int
SBPS_STRETCH: int
ID_INDICATOR_EXT: int
ID_INDICATOR_CAPS: int
ID_INDICATOR_NUM: int
ID_INDICATOR_SCRL: int
ID_INDICATOR_OVR: int
ID_INDICATOR_REC: int
ID_INDICATOR_KANA: int
ID_SEPARATOR: int
AFX_IDW_CONTROLBAR_FIRST: int
AFX_IDW_CONTROLBAR_LAST: int
AFX_IDW_TOOLBAR: int
AFX_IDW_STATUS_BAR: int
AFX_IDW_PREVIEW_BAR: int
AFX_IDW_RESIZE_BAR: int
AFX_IDW_DOCKBAR_TOP: int
AFX_IDW_DOCKBAR_LEFT: int
AFX_IDW_DOCKBAR_RIGHT: int
AFX_IDW_DOCKBAR_BOTTOM: int
AFX_IDW_DOCKBAR_FLOAT: int

def AFX_CONTROLBAR_MASK(nIDC): ...

AFX_IDW_PANE_FIRST: int
AFX_IDW_PANE_LAST: int
AFX_IDW_HSCROLL_FIRST: int
AFX_IDW_VSCROLL_FIRST: int
AFX_IDW_SIZE_BOX: int
AFX_IDW_PANE_SAVE: int
AFX_IDS_APP_TITLE: int
AFX_IDS_IDLEMESSAGE: int
AFX_IDS_HELPMODEMESSAGE: int
AFX_IDS_APP_TITLE_EMBEDDING: int
AFX_IDS_COMPANY_NAME: int
AFX_IDS_OBJ_TITLE_INPLACE: int
ID_FILE_NEW: int
ID_FILE_OPEN: int
ID_FILE_CLOSE: int
ID_FILE_SAVE: int
ID_FILE_SAVE_AS: int
ID_FILE_PAGE_SETUP: int
ID_FILE_PRINT_SETUP: int
ID_FILE_PRINT: int
ID_FILE_PRINT_DIRECT: int
ID_FILE_PRINT_PREVIEW: int
ID_FILE_UPDATE: int
ID_FILE_SAVE_COPY_AS: int
ID_FILE_SEND_MAIL: int
ID_FILE_MRU_FIRST: int
ID_FILE_MRU_FILE1: int
ID_FILE_MRU_FILE2: int
ID_FILE_MRU_FILE3: int
ID_FILE_MRU_FILE4: int
ID_FILE_MRU_FILE5: int
ID_FILE_MRU_FILE6: int
ID_FILE_MRU_FILE7: int
ID_FILE_MRU_FILE8: int
ID_FILE_MRU_FILE9: int
ID_FILE_MRU_FILE10: int
ID_FILE_MRU_FILE11: int
ID_FILE_MRU_FILE12: int
ID_FILE_MRU_FILE13: int
ID_FILE_MRU_FILE14: int
ID_FILE_MRU_FILE15: int
ID_FILE_MRU_FILE16: int
ID_FILE_MRU_LAST: int
ID_EDIT_CLEAR: int
ID_EDIT_CLEAR_ALL: int
ID_EDIT_COPY: int
ID_EDIT_CUT: int
ID_EDIT_FIND: int
ID_EDIT_PASTE: int
ID_EDIT_PASTE_LINK: int
ID_EDIT_PASTE_SPECIAL: int
ID_EDIT_REPEAT: int
ID_EDIT_REPLACE: int
ID_EDIT_SELECT_ALL: int
ID_EDIT_UNDO: int
ID_EDIT_REDO: int
ID_WINDOW_NEW: int
ID_WINDOW_ARRANGE: int
ID_WINDOW_CASCADE: int
ID_WINDOW_TILE_HORZ: int
ID_WINDOW_TILE_VERT: int
ID_WINDOW_SPLIT: int
AFX_IDM_WINDOW_FIRST: int
AFX_IDM_WINDOW_LAST: int
AFX_IDM_FIRST_MDICHILD: int
ID_APP_ABOUT: int
ID_APP_EXIT: int
ID_HELP_INDEX: int
ID_HELP_FINDER: int
ID_HELP_USING: int
ID_CONTEXT_HELP: int
ID_HELP: int
ID_DEFAULT_HELP: int
ID_NEXT_PANE: int
ID_PREV_PANE: int
ID_FORMAT_FONT: int
ID_OLE_INSERT_NEW: int
ID_OLE_EDIT_LINKS: int
ID_OLE_EDIT_CONVERT: int
ID_OLE_EDIT_CHANGE_ICON: int
ID_OLE_EDIT_PROPERTIES: int
ID_OLE_VERB_FIRST: int
ID_OLE_VERB_LAST: int
AFX_ID_PREVIEW_CLOSE: int
AFX_ID_PREVIEW_NUMPAGE: int
AFX_ID_PREVIEW_NEXT: int
AFX_ID_PREVIEW_PREV: int
AFX_ID_PREVIEW_PRINT: int
AFX_ID_PREVIEW_ZOOMIN: int
AFX_ID_PREVIEW_ZOOMOUT: int
ID_VIEW_TOOLBAR: int
ID_VIEW_STATUS_BAR: int
ID_RECORD_FIRST: int
ID_RECORD_LAST: int
ID_RECORD_NEXT: int
ID_RECORD_PREV: int
IDC_STATIC: int
AFX_IDS_SCFIRST: int
AFX_IDS_SCSIZE: int
AFX_IDS_SCMOVE: int
AFX_IDS_SCMINIMIZE: int
AFX_IDS_SCMAXIMIZE: int
AFX_IDS_SCNEXTWINDOW: int
AFX_IDS_SCPREVWINDOW: int
AFX_IDS_SCCLOSE: int
AFX_IDS_SCRESTORE: int
AFX_IDS_SCTASKLIST: int
AFX_IDS_MDICHILD: int
AFX_IDS_DESKACCESSORY: int
AFX_IDS_OPENFILE: int
AFX_IDS_SAVEFILE: int
AFX_IDS_ALLFILTER: int
AFX_IDS_UNTITLED: int
AFX_IDS_SAVEFILECOPY: int
AFX_IDS_PREVIEW_CLOSE: int
AFX_IDS_UNNAMED_FILE: int
AFX_IDS_ABOUT: int
AFX_IDS_HIDE: int
AFX_IDP_NO_ERROR_AVAILABLE: int
AFX_IDS_NOT_SUPPORTED_EXCEPTION: int
AFX_IDS_RESOURCE_EXCEPTION: int
AFX_IDS_MEMORY_EXCEPTION: int
AFX_IDS_USER_EXCEPTION: int
AFX_IDS_PRINTONPORT: int
AFX_IDS_ONEPAGE: int
AFX_IDS_TWOPAGE: int
AFX_IDS_PRINTPAGENUM: int
AFX_IDS_PREVIEWPAGEDESC: int
AFX_IDS_PRINTDEFAULTEXT: int
AFX_IDS_PRINTDEFAULT: int
AFX_IDS_PRINTFILTER: int
AFX_IDS_PRINTCAPTION: int
AFX_IDS_PRINTTOFILE: int
AFX_IDS_OBJECT_MENUITEM: int
AFX_IDS_EDIT_VERB: int
AFX_IDS_ACTIVATE_VERB: int
AFX_IDS_CHANGE_LINK: int
AFX_IDS_AUTO: int
AFX_IDS_MANUAL: int
AFX_IDS_FROZEN: int
AFX_IDS_ALL_FILES: int
AFX_IDS_SAVE_MENU: int
AFX_IDS_UPDATE_MENU: int
AFX_IDS_SAVE_AS_MENU: int
AFX_IDS_SAVE_COPY_AS_MENU: int
AFX_IDS_EXIT_MENU: int
AFX_IDS_UPDATING_ITEMS: int
AFX_IDS_METAFILE_FORMAT: int
AFX_IDS_DIB_FORMAT: int
AFX_IDS_BITMAP_FORMAT: int
AFX_IDS_LINKSOURCE_FORMAT: int
AFX_IDS_EMBED_FORMAT: int
AFX_IDS_PASTELINKEDTYPE: int
AFX_IDS_UNKNOWNTYPE: int
AFX_IDS_RTF_FORMAT: int
AFX_IDS_TEXT_FORMAT: int
AFX_IDS_INVALID_CURRENCY: int
AFX_IDS_INVALID_DATETIME: int
AFX_IDS_INVALID_DATETIMESPAN: int
AFX_IDP_INVALID_FILENAME: int
AFX_IDP_FAILED_TO_OPEN_DOC: int
AFX_IDP_FAILED_TO_SAVE_DOC: int
AFX_IDP_ASK_TO_SAVE: int
AFX_IDP_FAILED_TO_CREATE_DOC: int
AFX_IDP_FILE_TOO_LARGE: int
AFX_IDP_FAILED_TO_START_PRINT: int
AFX_IDP_FAILED_TO_LAUNCH_HELP: int
AFX_IDP_INTERNAL_FAILURE: int
AFX_IDP_COMMAND_FAILURE: int
AFX_IDP_FAILED_MEMORY_ALLOC: int
AFX_IDP_PARSE_INT: int
AFX_IDP_PARSE_REAL: int
AFX_IDP_PARSE_INT_RANGE: int
AFX_IDP_PARSE_REAL_RANGE: int
AFX_IDP_PARSE_STRING_SIZE: int
AFX_IDP_PARSE_RADIO_BUTTON: int
AFX_IDP_PARSE_BYTE: int
AFX_IDP_PARSE_UINT: int
AFX_IDP_PARSE_DATETIME: int
AFX_IDP_PARSE_CURRENCY: int
AFX_IDP_FAILED_INVALID_FORMAT: int
AFX_IDP_FAILED_INVALID_PATH: int
AFX_IDP_FAILED_DISK_FULL: int
AFX_IDP_FAILED_ACCESS_READ: int
AFX_IDP_FAILED_ACCESS_WRITE: int
AFX_IDP_FAILED_IO_ERROR_READ: int
AFX_IDP_FAILED_IO_ERROR_WRITE: int
AFX_IDP_STATIC_OBJECT: int
AFX_IDP_FAILED_TO_CONNECT: int
AFX_IDP_SERVER_BUSY: int
AFX_IDP_BAD_VERB: int
AFX_IDP_FAILED_TO_NOTIFY: int
AFX_IDP_FAILED_TO_LAUNCH: int
AFX_IDP_ASK_TO_UPDATE: int
AFX_IDP_FAILED_TO_UPDATE: int
AFX_IDP_FAILED_TO_REGISTER: int
AFX_IDP_FAILED_TO_AUTO_REGISTER: int
AFX_IDP_FAILED_TO_CONVERT: int
AFX_IDP_GET_NOT_SUPPORTED: int
AFX_IDP_SET_NOT_SUPPORTED: int
AFX_IDP_ASK_TO_DISCARD: int
AFX_IDP_FAILED_TO_CREATE: int
AFX_IDP_FAILED_MAPI_LOAD: int
AFX_IDP_INVALID_MAPI_DLL: int
AFX_IDP_FAILED_MAPI_SEND: int
AFX_IDP_FILE_NONE: int
AFX_IDP_FILE_GENERIC: int
AFX_IDP_FILE_NOT_FOUND: int
AFX_IDP_FILE_BAD_PATH: int
AFX_IDP_FILE_TOO_MANY_OPEN: int
AFX_IDP_FILE_ACCESS_DENIED: int
AFX_IDP_FILE_INVALID_FILE: int
AFX_IDP_FILE_REMOVE_CURRENT: int
AFX_IDP_FILE_DIR_FULL: int
AFX_IDP_FILE_BAD_SEEK: int
AFX_IDP_FILE_HARD_IO: int
AFX_IDP_FILE_SHARING: int
AFX_IDP_FILE_LOCKING: int
AFX_IDP_FILE_DISKFULL: int
AFX_IDP_FILE_EOF: int
AFX_IDP_ARCH_NONE: int
AFX_IDP_ARCH_GENERIC: int
AFX_IDP_ARCH_READONLY: int
AFX_IDP_ARCH_ENDOFFILE: int
AFX_IDP_ARCH_WRITEONLY: int
AFX_IDP_ARCH_BADINDEX: int
AFX_IDP_ARCH_BADCLASS: int
AFX_IDP_ARCH_BADSCHEMA: int
AFX_IDS_OCC_SCALEUNITS_PIXELS: int
AFX_IDS_STATUS_FONT: int
AFX_IDS_TOOLTIP_FONT: int
AFX_IDS_UNICODE_FONT: int
AFX_IDS_MINI_FONT: int
AFX_IDP_SQL_FIRST: int
AFX_IDP_SQL_CONNECT_FAIL: int
AFX_IDP_SQL_RECORDSET_FORWARD_ONLY: int
AFX_IDP_SQL_EMPTY_COLUMN_LIST: int
AFX_IDP_SQL_FIELD_SCHEMA_MISMATCH: int
AFX_IDP_SQL_ILLEGAL_MODE: int
AFX_IDP_SQL_MULTIPLE_ROWS_AFFECTED: int
AFX_IDP_SQL_NO_CURRENT_RECORD: int
AFX_IDP_SQL_NO_ROWS_AFFECTED: int
AFX_IDP_SQL_RECORDSET_READONLY: int
AFX_IDP_SQL_SQL_NO_TOTAL: int
AFX_IDP_SQL_ODBC_LOAD_FAILED: int
AFX_IDP_SQL_DYNASET_NOT_SUPPORTED: int
AFX_IDP_SQL_SNAPSHOT_NOT_SUPPORTED: int
AFX_IDP_SQL_API_CONFORMANCE: int
AFX_IDP_SQL_SQL_CONFORMANCE: int
AFX_IDP_SQL_NO_DATA_FOUND: int
AFX_IDP_SQL_ROW_UPDATE_NOT_SUPPORTED: int
AFX_IDP_SQL_ODBC_V2_REQUIRED: int
AFX_IDP_SQL_NO_POSITIONED_UPDATES: int
AFX_IDP_SQL_LOCK_MODE_NOT_SUPPORTED: int
AFX_IDP_SQL_DATA_TRUNCATED: int
AFX_IDP_SQL_ROW_FETCH: int
AFX_IDP_SQL_INCORRECT_ODBC: int
AFX_IDP_SQL_UPDATE_DELETE_FAILED: int
AFX_IDP_SQL_DYNAMIC_CURSOR_NOT_SUPPORTED: int
AFX_IDP_DAO_FIRST: int
AFX_IDP_DAO_ENGINE_INITIALIZATION: int
AFX_IDP_DAO_DFX_BIND: int
AFX_IDP_DAO_OBJECT_NOT_OPEN: int
AFX_IDP_DAO_ROWTOOSHORT: int
AFX_IDP_DAO_BADBINDINFO: int
AFX_IDP_DAO_COLUMNUNAVAILABLE: int
AFX_IDC_LISTBOX: int
AFX_IDC_CHANGE: int
AFX_IDC_PRINT_DOCNAME: int
AFX_IDC_PRINT_PRINTERNAME: int
AFX_IDC_PRINT_PORTNAME: int
AFX_IDC_PRINT_PAGENUM: int
ID_APPLY_NOW: int
ID_WIZBACK: int
ID_WIZNEXT: int
ID_WIZFINISH: int
AFX_IDC_TAB_CONTROL: int
AFX_IDD_FILEOPEN: int
AFX_IDD_FILESAVE: int
AFX_IDD_FONT: int
AFX_IDD_COLOR: int
AFX_IDD_PRINT: int
AFX_IDD_PRINTSETUP: int
AFX_IDD_FIND: int
AFX_IDD_REPLACE: int
AFX_IDD_NEWTYPEDLG: int
AFX_IDD_PRINTDLG: int
AFX_IDD_PREVIEW_TOOLBAR: int
AFX_IDD_PREVIEW_SHORTTOOLBAR: int
AFX_IDD_INSERTOBJECT: int
AFX_IDD_CHANGEICON: int
AFX_IDD_CONVERT: int
AFX_IDD_PASTESPECIAL: int
AFX_IDD_EDITLINKS: int
AFX_IDD_FILEBROWSE: int
AFX_IDD_BUSY: int
AFX_IDD_OBJECTPROPERTIES: int
AFX_IDD_CHANGESOURCE: int
AFX_IDC_CONTEXTHELP: int
AFX_IDC_MAGNIFY: int
AFX_IDC_SMALLARROWS: int
AFX_IDC_HSPLITBAR: int
AFX_IDC_VSPLITBAR: int
AFX_IDC_NODROPCRSR: int
AFX_IDC_TRACKNWSE: int
AFX_IDC_TRACKNESW: int
AFX_IDC_TRACKNS: int
AFX_IDC_TRACKWE: int
AFX_IDC_TRACK4WAY: int
AFX_IDC_MOVE4WAY: int
AFX_IDB_MINIFRAME_MENU: int
AFX_IDB_CHECKLISTBOX_NT: int
AFX_IDB_CHECKLISTBOX_95: int
AFX_IDR_PREVIEW_ACCEL: int
AFX_IDI_STD_MDIFRAME: int
AFX_IDI_STD_FRAME: int
AFX_IDC_FONTPROP: int
AFX_IDC_FONTNAMES: int
AFX_IDC_FONTSTYLES: int
AFX_IDC_FONTSIZES: int
AFX_IDC_STRIKEOUT: int
AFX_IDC_UNDERLINE: int
AFX_IDC_SAMPLEBOX: int
AFX_IDC_COLOR_BLACK: int
AFX_IDC_COLOR_WHITE: int
AFX_IDC_COLOR_RED: int
AFX_IDC_COLOR_GREEN: int
AFX_IDC_COLOR_BLUE: int
AFX_IDC_COLOR_YELLOW: int
AFX_IDC_COLOR_MAGENTA: int
AFX_IDC_COLOR_CYAN: int
AFX_IDC_COLOR_GRAY: int
AFX_IDC_COLOR_LIGHTGRAY: int
AFX_IDC_COLOR_DARKRED: int
AFX_IDC_COLOR_DARKGREEN: int
AFX_IDC_COLOR_DARKBLUE: int
AFX_IDC_COLOR_LIGHTBROWN: int
AFX_IDC_COLOR_DARKMAGENTA: int
AFX_IDC_COLOR_DARKCYAN: int
AFX_IDC_COLORPROP: int
AFX_IDC_SYSTEMCOLORS: int
AFX_IDC_PROPNAME: int
AFX_IDC_PICTURE: int
AFX_IDC_BROWSE: int
AFX_IDC_CLEAR: int
AFX_IDD_PROPPAGE_COLOR: int
AFX_IDD_PROPPAGE_FONT: int
AFX_IDD_PROPPAGE_PICTURE: int
AFX_IDB_TRUETYPE: int
AFX_IDS_PROPPAGE_UNKNOWN: int
AFX_IDS_COLOR_DESKTOP: int
AFX_IDS_COLOR_APPWORKSPACE: int
AFX_IDS_COLOR_WNDBACKGND: int
AFX_IDS_COLOR_WNDTEXT: int
AFX_IDS_COLOR_MENUBAR: int
AFX_IDS_COLOR_MENUTEXT: int
AFX_IDS_COLOR_ACTIVEBAR: int
AFX_IDS_COLOR_INACTIVEBAR: int
AFX_IDS_COLOR_ACTIVETEXT: int
AFX_IDS_COLOR_INACTIVETEXT: int
AFX_IDS_COLOR_ACTIVEBORDER: int
AFX_IDS_COLOR_INACTIVEBORDER: int
AFX_IDS_COLOR_WNDFRAME: int
AFX_IDS_COLOR_SCROLLBARS: int
AFX_IDS_COLOR_BTNFACE: int
AFX_IDS_COLOR_BTNSHADOW: int
AFX_IDS_COLOR_BTNTEXT: int
AFX_IDS_COLOR_BTNHIGHLIGHT: int
AFX_IDS_COLOR_DISABLEDTEXT: int
AFX_IDS_COLOR_HIGHLIGHT: int
AFX_IDS_COLOR_HIGHLIGHTTEXT: int
AFX_IDS_REGULAR: int
AFX_IDS_BOLD: int
AFX_IDS_ITALIC: int
AFX_IDS_BOLDITALIC: int
AFX_IDS_SAMPLETEXT: int
AFX_IDS_DISPLAYSTRING_FONT: int
AFX_IDS_DISPLAYSTRING_COLOR: int
AFX_IDS_DISPLAYSTRING_PICTURE: int
AFX_IDS_PICTUREFILTER: int
AFX_IDS_PICTYPE_UNKNOWN: int
AFX_IDS_PICTYPE_NONE: int
AFX_IDS_PICTYPE_BITMAP: int
AFX_IDS_PICTYPE_METAFILE: int
AFX_IDS_PICTYPE_ICON: int
AFX_IDS_COLOR_PPG: int
AFX_IDS_COLOR_PPG_CAPTION: int
AFX_IDS_FONT_PPG: int
AFX_IDS_FONT_PPG_CAPTION: int
AFX_IDS_PICTURE_PPG: int
AFX_IDS_PICTURE_PPG_CAPTION: int
AFX_IDS_PICTUREBROWSETITLE: int
AFX_IDS_BORDERSTYLE_0: int
AFX_IDS_BORDERSTYLE_1: int
AFX_IDS_VERB_EDIT: int
AFX_IDS_VERB_PROPERTIES: int
AFX_IDP_PICTURECANTOPEN: int
AFX_IDP_PICTURECANTLOAD: int
AFX_IDP_PICTURETOOLARGE: int
AFX_IDP_PICTUREREADFAILED: int
AFX_IDP_E_ILLEGALFUNCTIONCALL: int
AFX_IDP_E_OVERFLOW: int
AFX_IDP_E_OUTOFMEMORY: int
AFX_IDP_E_DIVISIONBYZERO: int
AFX_IDP_E_OUTOFSTRINGSPACE: int
AFX_IDP_E_OUTOFSTACKSPACE: int
AFX_IDP_E_BADFILENAMEORNUMBER: int
AFX_IDP_E_FILENOTFOUND: int
AFX_IDP_E_BADFILEMODE: int
AFX_IDP_E_FILEALREADYOPEN: int
AFX_IDP_E_DEVICEIOERROR: int
AFX_IDP_E_FILEALREADYEXISTS: int
AFX_IDP_E_BADRECORDLENGTH: int
AFX_IDP_E_DISKFULL: int
AFX_IDP_E_BADRECORDNUMBER: int
AFX_IDP_E_BADFILENAME: int
AFX_IDP_E_TOOMANYFILES: int
AFX_IDP_E_DEVICEUNAVAILABLE: int
AFX_IDP_E_PERMISSIONDENIED: int
AFX_IDP_E_DISKNOTREADY: int
AFX_IDP_E_PATHFILEACCESSERROR: int
AFX_IDP_E_PATHNOTFOUND: int
AFX_IDP_E_INVALIDPATTERNSTRING: int
AFX_IDP_E_INVALIDUSEOFNULL: int
AFX_IDP_E_INVALIDFILEFORMAT: int
AFX_IDP_E_INVALIDPROPERTYVALUE: int
AFX_IDP_E_INVALIDPROPERTYARRAYINDEX: int
AFX_IDP_E_SETNOTSUPPORTEDATRUNTIME: int
AFX_IDP_E_SETNOTSUPPORTED: int
AFX_IDP_E_NEEDPROPERTYARRAYINDEX: int
AFX_IDP_E_SETNOTPERMITTED: int
AFX_IDP_E_GETNOTSUPPORTEDATRUNTIME: int
AFX_IDP_E_GETNOTSUPPORTED: int
AFX_IDP_E_PROPERTYNOTFOUND: int
AFX_IDP_E_INVALIDCLIPBOARDFORMAT: int
AFX_IDP_E_INVALIDPICTURE: int
AFX_IDP_E_PRINTERERROR: int
AFX_IDP_E_CANTSAVEFILETOTEMP: int
AFX_IDP_E_SEARCHTEXTNOTFOUND: int
AFX_IDP_E_REPLACEMENTSTOOLONG: int
